@@ -23,7 +23,7 @@ from textwrap import dedent
 from .__init__ import E, WINDOWS, VT100, PY2, unicode
 from .__version__ import S_VERSION, S_BUILD_DT, CODENAME
 from .svchub import SvcHub
-from .util import py_desc, align_tab, IMPLICATIONS, alltrace
+from .util import py_desc, align_tab, IMPLICATIONS
 
 HAVE_SSL = True
 try:
@@ -191,16 +191,6 @@ def sighandler(sig=None, frame=None):
     print("\n".join(msg))
 
 
-def stackmon(fp, ival):
-    ctr = 0
-    while True:
-        ctr += 1
-        time.sleep(ival)
-        st = "{}, {}\n{}".format(ctr, time.time(), alltrace())
-        with open(fp, "wb") as f:
-            f.write(st.encode("utf-8", "replace"))
-
-
 def run_argparse(argv, formatter):
     ap = argparse.ArgumentParser(
         formatter_class=formatter,
@@ -329,8 +319,9 @@ def run_argparse(argv, formatter):
     ap2.add_argument("-e2tsr", action="store_true", help="rescan all metadata, sets -e2ts")
     ap2.add_argument("--hist", metavar="PATH", type=u, help="where to store volume state")
     ap2.add_argument("--no-hash", action="store_true", help="disable hashing during e2ds folder scans")
-    ap2.add_argument("--no-mutagen", action="store_true", help="use ffprobe for tags instead")
+    ap2.add_argument("--no-mutagen", action="store_true", help="use FFprobe for tags instead")
     ap2.add_argument("--no-mtag-mt", action="store_true", help="disable tag-read parallelism")
+    ap2.add_argument("--no-mtag-ff", action="store_true", help="never use FFprobe as tag reader")
     ap2.add_argument("-mtm", metavar="M=t,t,t", type=u, action="append", help="add/replace metadata mapping")
     ap2.add_argument("-mte", metavar="M,M,M", type=u, help="tags to index/display (comma-sep.)",
         default="circle,album,.tn,artist,title,.bpm,key,.dur,.q,.vq,.aq,ac,vc,res,.fps")
@@ -346,6 +337,7 @@ def run_argparse(argv, formatter):
     ap2.add_argument("--no-fastboot", action="store_true", help="wait for up2k indexing")
     ap2.add_argument("--no-htp", action="store_true", help="disable httpserver threadpool, create threads as-needed instead")
     ap2.add_argument("--stackmon", metavar="P,S", type=u, help="write stacktrace to Path every S second")
+    ap2.add_argument("--log-thrs", metavar="SEC", type=float, help="list active threads every SEC")
     
     return ap.parse_args(args=argv[1:])
     # fmt: on
@@ -385,16 +377,6 @@ def main(argv=None):
     except AssertionError:
         al = run_argparse(argv, Dodge11874)
 
-    if al.stackmon:
-        fp, f = al.stackmon.rsplit(",", 1)
-        f = int(f)
-        t = threading.Thread(
-            target=stackmon,
-            args=(fp, f),
-        )
-        t.daemon = True
-        t.start()
-
     # propagate implications
     for k1, k2 in IMPLICATIONS:
         if getattr(al, k1):
