@@ -37,7 +37,6 @@ class HttpCli(object):
         self.ip = conn.addr[0]
         self.addr = conn.addr  # type: tuple[str, int]
         self.args = conn.args
-        self.is_mp = conn.is_mp
         self.asrv = conn.asrv  # type: AuthSrv
         self.ico = conn.ico
         self.thumbcli = conn.thumbcli
@@ -227,7 +226,7 @@ class HttpCli(object):
             except Pebkac:
                 return False
 
-    def send_headers(self, length, status=200, mime=None, headers={}):
+    def send_headers(self, length, status=200, mime=None, headers=None):
         response = ["{} {} {}".format(self.http_ver, status, HTTPCODE[status])]
 
         if length is not None:
@@ -237,7 +236,8 @@ class HttpCli(object):
         response.append("Connection: " + ("Keep-Alive" if self.keepalive else "Close"))
 
         # headers{} overrides anything set previously
-        self.out_headers.update(headers)
+        if headers:
+            self.out_headers.update(headers)
 
         # default to utf8 html if no content-type is set
         if not mime:
@@ -254,7 +254,7 @@ class HttpCli(object):
         except:
             raise Pebkac(400, "client d/c while replying headers")
 
-    def reply(self, body, status=200, mime=None, headers={}):
+    def reply(self, body, status=200, mime=None, headers=None):
         # TODO something to reply with user-supplied values safely
         self.send_headers(len(body), status, mime, headers)
 
@@ -270,7 +270,7 @@ class HttpCli(object):
         self.log(body.rstrip())
         self.reply(b"<pre>" + body.encode("utf-8") + b"\r\n", *list(args), **kwargs)
 
-    def urlq(self, add={}, rm=[]):
+    def urlq(self, add, rm):
         """
         generates url query based on uparam (b, pw, all others)
         removing anything in rm, adding pairs in add
@@ -342,6 +342,9 @@ class HttpCli(object):
         if "tree" in self.uparam:
             return self.tx_tree()
 
+        if "stack" in self.uparam:
+            return self.tx_stack()
+
         # conditional redirect to single volumes
         if self.vpath == "" and not self.ouparam:
             nread = len(self.rvol)
@@ -371,9 +374,6 @@ class HttpCli(object):
         if "scan" in self.uparam:
             return self.scanvol()
 
-        if "stack" in self.uparam:
-            return self.tx_stack()
-
         return self.tx_browser()
 
     def handle_options(self):
@@ -795,7 +795,7 @@ class HttpCli(object):
         vfs, rem = self.asrv.vfs.get(self.vpath, self.uname, False, True)
         self._assert_safe_rem(rem)
 
-        sanitized = sanitize_fn(new_dir)
+        sanitized = sanitize_fn(new_dir, "", [])
 
         if not nullwrite:
             fdir = os.path.join(vfs.realpath, rem)
@@ -832,7 +832,7 @@ class HttpCli(object):
         if not new_file.endswith(".md"):
             new_file += ".md"
 
-        sanitized = sanitize_fn(new_file)
+        sanitized = sanitize_fn(new_file, "", [])
 
         if not nullwrite:
             fdir = os.path.join(vfs.realpath, rem)
@@ -865,7 +865,7 @@ class HttpCli(object):
                 if p_file and not nullwrite:
                     fdir = os.path.join(vfs.realpath, rem)
                     fname = sanitize_fn(
-                        p_file, bad=[".prologue.html", ".epilogue.html"]
+                        p_file, "", [".prologue.html", ".epilogue.html"]
                     )
 
                     if not os.path.isdir(fsenc(fdir)):
@@ -1312,7 +1312,7 @@ class HttpCli(object):
 
         fgen = vn.zipgen(rem, items, self.uname, dots, not self.args.no_scandir)
         # for f in fgen: print(repr({k: f[k] for k in ["vp", "ap"]}))
-        bgen = packer(fgen, utf8="utf" in uarg, pre_crc="crc" in uarg)
+        bgen = packer(self.log, fgen, utf8="utf" in uarg, pre_crc="crc" in uarg)
         bsent = 0
         for buf in bgen.gen():
             if not buf:
@@ -1376,7 +1376,7 @@ class HttpCli(object):
             for c, v in [[b"&", 4], [b"<", 3], [b">", 3]]:
                 sz_md += (len(buf) - len(buf.replace(c, b""))) * v
 
-        file_ts = max(ts_md, ts_html)
+        file_ts = max(ts_md, ts_html, E.t0)
         file_lastmod, do_send = self._chk_lastmod(file_ts)
         self.out_headers["Last-Modified"] = file_lastmod
         self.out_headers.update(NO_CACHE)
@@ -1423,7 +1423,7 @@ class HttpCli(object):
         return True
 
     def tx_mounts(self):
-        suf = self.urlq(rm=["h"])
+        suf = self.urlq({}, ["h"])
         rvol, wvol, avol = [
             [("/" + x).rstrip("/") + "/" for x in y]
             for y in [self.rvol, self.wvol, self.avol]
@@ -1634,7 +1634,7 @@ class HttpCli(object):
         if self.writable:
             perms.append("write")
 
-        url_suf = self.urlq()
+        url_suf = self.urlq({}, [])
         is_ls = "ls" in self.uparam
 
         tpl = "browser"
