@@ -195,7 +195,7 @@ class Up2k(object):
 
         return True, ret
 
-    def init_indexes(self, all_vols, scan_vols=[]):
+    def init_indexes(self, all_vols, scan_vols=None):
         self.pp = ProgressPrinter()
         vols = all_vols.values()
         t0 = time.time()
@@ -304,7 +304,7 @@ class Up2k(object):
         self.log(msg.format(len(vols), time.time() - t0))
 
         if needed_mutagen:
-            msg = "could not read tags because no backends are available (mutagen or ffprobe)"
+            msg = "could not read tags because no backends are available (Mutagen or FFprobe)"
             self.log(msg, c=1)
 
         thr = None
@@ -596,7 +596,7 @@ class Up2k(object):
             c2 = conn.cursor()
             c3 = conn.cursor()
             n_left = cur.execute("select count(w) from up").fetchone()[0]
-            for w, rd, fn in cur.execute("select w, rd, fn from up"):
+            for w, rd, fn in cur.execute("select w, rd, fn from up order by rd, fn"):
                 n_left -= 1
                 q = "select w from mt where w = ?"
                 if c2.execute(q, (w[:16],)).fetchone():
@@ -991,7 +991,7 @@ class Up2k(object):
                 if cj["ptop"] not in self.registry:
                     raise Pebkac(410, "location unavailable")
 
-        cj["name"] = sanitize_fn(cj["name"], bad=[".prologue.html", ".epilogue.html"])
+        cj["name"] = sanitize_fn(cj["name"], "", [".prologue.html", ".epilogue.html"])
         cj["poke"] = time.time()
         wark = self._get_wark(cj)
         now = time.time()
@@ -1363,19 +1363,22 @@ class Up2k(object):
                         self.log("could not unsparse [{}]".format(path), 3)
 
     def _snapshot(self):
-        persist_interval = 30  # persist unfinished uploads index every 30 sec
-        discard_interval = 21600  # drop unfinished uploads after 6 hours inactivity
-        prev = {}
+        self.snap_persist_interval = 300  # persist unfinished index every 5 min
+        self.snap_discard_interval = 21600  # drop unfinished after 6 hours inactivity
+        self.snap_prev = {}
         while True:
-            time.sleep(persist_interval)
-            with self.mutex:
-                for k, reg in self.registry.items():
-                    self._snap_reg(prev, k, reg, discard_interval)
+            time.sleep(self.snap_persist_interval)
+            self.do_snapshot()
 
-    def _snap_reg(self, prev, ptop, reg, discard_interval):
+    def do_snapshot(self):
+        with self.mutex:
+            for k, reg in self.registry.items():
+                self._snap_reg(k, reg)
+
+    def _snap_reg(self, ptop, reg):
         now = time.time()
         histpath = self.asrv.vfs.histtab[ptop]
-        rm = [x for x in reg.values() if now - x["poke"] > discard_interval]
+        rm = [x for x in reg.values() if now - x["poke"] > self.snap_discard_interval]
         if rm:
             m = "dropping {} abandoned uploads in {}".format(len(rm), ptop)
             vis = [self._vis_job_progress(x) for x in rm]
@@ -1397,15 +1400,15 @@ class Up2k(object):
 
         path = os.path.join(histpath, "up2k.snap")
         if not reg:
-            if ptop not in prev or prev[ptop] is not None:
-                prev[ptop] = None
+            if ptop not in self.snap_prev or self.snap_prev[ptop] is not None:
+                self.snap_prev[ptop] = None
                 if os.path.exists(fsenc(path)):
                     os.unlink(fsenc(path))
             return
 
         newest = max(x["poke"] for _, x in reg.items()) if reg else 0
         etag = [len(reg), newest]
-        if etag == prev.get(ptop):
+        if etag == self.snap_prev.get(ptop):
             return
 
         try:
@@ -1421,7 +1424,7 @@ class Up2k(object):
         atomic_move(path2, path)
 
         self.log("snap: {} |{}|".format(path, len(reg.keys())))
-        prev[ptop] = etag
+        self.snap_prev[ptop] = etag
 
     def _tagger(self):
         with self.mutex:
@@ -1489,6 +1492,11 @@ class Up2k(object):
             self.n_hashq += 1
         # self.log("hashq {} push {}/{}/{}".format(self.n_hashq, ptop, rd, fn))
 
+    def shutdown(self):
+        if hasattr(self, "snap_prev"):
+            self.log("writing snapshot")
+            self.do_snapshot()
+
 
 def up2k_chunksize(filesize):
     chunksize = 1024 * 1024
@@ -1504,7 +1512,7 @@ def up2k_chunksize(filesize):
 
 
 def up2k_wark_from_hashlist(salt, filesize, hashes):
-    """ server-reproducible file identifier, independent of name or location """
+    """server-reproducible file identifier, independent of name or location"""
     ident = [salt, str(filesize)]
     ident.extend(hashes)
     ident = "\n".join(ident)
