@@ -37,6 +37,7 @@ ebi('widget').innerHTML = (
 	' href="#" id="npirc" tt="copy irc-formatted track info">📋irc</a><a' +
 	' href="#" id="nptxt" tt="copy plaintext track info">📋txt</a>' +
 	'</span><a' +
+	'	href="#" id="wtgrid">田</a><a' +
 	'	href="#" id="wtico">♫</a>' +
 	'</div>' +
 	'<div id="widgeti">' +
@@ -149,8 +150,8 @@ ebi('op_cfg').innerHTML = (
 ebi('tree').innerHTML = (
 	'<div id="treeh">\n' +
 	'	<a href="#" id="detree" tt="show breadcrumbs$NHotkey: B">🍞...</a>\n' +
-	'	<a href="#" class="btn" step="2" id="twobytwo">+</a>\n' +
-	'	<a href="#" class="btn" step="-2" id="twig">&ndash;</a>\n' +
+	'	<a href="#" class="btn" step="2" id="twobytwo" tt="Hotkey: A">+</a>\n' +
+	'	<a href="#" class="btn" step="-2" id="twig" tt="Hotkey: D">&ndash;</a>\n' +
 	'	<a href="#" class="tgl btn" id="dyntree" tt="autogrow as tree expands">a</a>\n' +
 	'</div>\n' +
 	'<ul id="treeul"></ul>\n' +
@@ -167,16 +168,19 @@ ebi('tree').innerHTML = (
 
 
 function opclick(e) {
-	ev(e);
-
 	var dest = this.getAttribute('data-dest');
+	swrite('opmode', dest || null);
+	if (ctrl(e))
+		return;
+
+	ev(e);
 	goto(dest);
 
-	swrite('opmode', dest || null);
-
 	var input = QS('.opview.act input:not([type="hidden"])')
-	if (input && !is_touch)
+	if (input && !is_touch) {
+		tt.skip = true;
 		input.focus();
+	}
 }
 
 
@@ -604,7 +608,7 @@ var widget = (function () {
 
 		m += '[' + cv + s2ms(mp.au.currentTime) + ck + '/' + cv + s2ms(mp.au.duration) + ck + ']';
 
-		var o = document.createElement('input');
+		var o = mknod('input');
 		o.style.cssText = 'position:fixed;top:45%;left:48%;padding:1em;z-index:9';
 		o.value = m;
 		document.body.appendChild(o);
@@ -1450,15 +1454,15 @@ function play_linked() {
 
 var thegrid = (function () {
 	var lfiles = ebi('files'),
-		gfiles = document.createElement('div');
+		gfiles = mknod('div');
 
 	gfiles.setAttribute('id', 'gfiles');
 	gfiles.style.display = 'none';
 	gfiles.innerHTML = (
 		'<div id="ghead">' +
 		'<a href="#" class="tgl btn" id="gridsel" tt="enable file selection; ctrl-click a file to override$NHotkey: S">multiselect</a> &nbsp; zoom ' +
-		'<a href="#" class="btn" z="-1.2" tt="Hotkey: A">&ndash;</a> ' +
-		'<a href="#" class="btn" z="1.2" tt="Hotkey: D">+</a> &nbsp; sort by: ' +
+		'<a href="#" class="btn" z="-1.2" tt="Hotkey: shift-A">&ndash;</a> ' +
+		'<a href="#" class="btn" z="1.2" tt="Hotkey: shift-D">+</a> &nbsp; sort by: ' +
 		'<a href="#" s="href">name</a>, ' +
 		'<a href="#" s="sz">size</a>, ' +
 		'<a href="#" s="ts">date</a>, ' +
@@ -1484,8 +1488,11 @@ var thegrid = (function () {
 		r.setdirty();
 	};
 
-	ebi('griden').onclick = function (e) {
+	ebi('griden').onclick = ebi('wtgrid').onclick = function (e) {
 		ev(e);
+		if (!this.closest)
+			return;
+
 		r.en = !r.en;
 		bcfg_set('griden', r.en);
 		if (r.en) {
@@ -1552,7 +1559,7 @@ var thegrid = (function () {
 	setsz();
 
 	function gclick(e) {
-		if (e && (e.ctrlKey || e.metaKey))
+		if (ctrl(e))
 			return true;
 
 		var oth = ebi(this.getAttribute('ref')),
@@ -1706,6 +1713,25 @@ var thegrid = (function () {
 })();
 
 
+function tree_scrollto() {
+	var act = QS('#treeul a.hl');
+	if (!act)
+		return;
+
+	var ctr = ebi('tree'),
+		ul = act.offsetParent,
+		em = parseFloat(getComputedStyle(act).fontSize),
+		top = act.offsetTop + ul.offsetTop,
+		min = top - 11 * em,
+		max = top - (ctr.offsetHeight - 10 * em);
+
+	if (ctr.scrollTop > min)
+		ctr.scrollTop = Math.floor(min);
+	else if (ctr.scrollTop < max)
+		ctr.scrollTop = Math.floor(max);
+}
+
+
 function tree_neigh(n) {
 	var links = QSA('#treeul li>a+a');
 	if (!links.length) {
@@ -1731,6 +1757,7 @@ function tree_neigh(n) {
 	if (act >= links.length)
 		act = 0;
 
+	treectl.dir_cb = tree_scrollto;
 	links[act].click();
 }
 
@@ -1756,6 +1783,9 @@ document.onkeydown = function (e) {
 	if (e.ctrlKey || e.altKey || e.metaKey || e.isComposing)
 		return;
 
+	if (QS('#bbox-overlay.visible'))
+		return;
+
 	var k = e.code + '', pos = -1, n;
 
 	if (e.shiftKey && k != 'KeyA' && k != 'KeyD')
@@ -1932,7 +1962,7 @@ document.onkeydown = function (e) {
 			for (var b = 1; b < sconf[a].length; b++) {
 				var k = sconf[a][b][0],
 					chk = 'srch_' + k + 'c',
-					tvs = ebi('srch_' + k + 'v').value.split(/ /g);
+					tvs = ebi('srch_' + k + 'v').value.split(/ +/g);
 
 				if (!ebi(chk).checked)
 					continue;
@@ -1945,7 +1975,7 @@ document.onkeydown = function (e) {
 					q += ' and ';
 
 					if (k == 'adv') {
-						q += tv.replace(/ /g, " and ").replace(/([=!><]=?)/, " $1 ");
+						q += tv.replace(/ +/g, " and ").replace(/([=!><]=?)/, " $1 ");
 						continue;
 					}
 
@@ -2297,7 +2327,7 @@ var treectl = (function () {
 	}
 
 	function treego(e) {
-		if (e && (e.ctrlKey || e.metaKey))
+		if (ctrl(e))
 			return true;
 
 		ev(e);
@@ -2516,7 +2546,7 @@ function apply_perms(newperms) {
 
 	var o = QSA('#ops>a[data-perm], #u2footfoot');
 	for (var a = 0; a < o.length; a++) {
-		var display = 'inline';
+		var display = '';
 		var needed = o[a].getAttribute('data-perm').split(' ');
 		for (var b = 0; b < needed.length; b++) {
 			if (!has(perms, needed[b])) {
@@ -2568,7 +2598,7 @@ function find_file_col(txt) {
 	for (var a = 0; a < tds.length; a++) {
 		var spans = tds[a].getElementsByTagName('span');
 		if (spans.length && spans[0].textContent == txt) {
-			min = tds[a].getAttribute('class').indexOf('min') !== -1;
+			min = (tds[a].getAttribute('class') || '').indexOf('min') !== -1;
 			i = a;
 			break;
 		}
@@ -2610,14 +2640,36 @@ function mk_files_header(taglist) {
 
 
 var filecols = (function () {
-	var hidden = jread('filecols', []);
+	var hidden = jread('filecols', []),
+		tts = {
+			"c": "action buttons",
+			"dur": "duration",
+			"q": "quality / bitrate",
+			"Ac": "audio codec",
+			"Vc": "video codec",
+			"Res": "resolution",
+			"T": "filetype",
+			"aq": "audio quality / bitrate",
+			"vq": "video quality / bitrate",
+			"pixfmt": "subsampling / pixel structure",
+			"resw": "horizontal resolution",
+			"resh": "veritcal resolution",
+			"acs": "audio channels",
+			"hz": "sample rate"
+		};
 
 	var add_btns = function () {
 		var ths = QSA('#files th>span');
 		for (var a = 0, aa = ths.length; a < aa; a++) {
-			var th = ths[a].parentElement;
+			var th = ths[a].parentElement,
+				ttv = tts[ths[a].textContent];
+
 			th.innerHTML = '<div class="cfg"><a href="#">-</a></div>' + ths[a].outerHTML;
 			th.getElementsByTagName('a')[0].onclick = ev_row_tgl;
+			if (ttv) {
+				th.setAttribute("tt", ttv);
+				th.setAttribute("ttd", "u");
+			}
 		}
 	};
 
@@ -2640,7 +2692,10 @@ var filecols = (function () {
 			hcols = ebi('hcols');
 
 		for (var a = 0; a < hidden.length; a++) {
-			html.push('<a href="#" class="btn">' + esc(hidden[a]) + '</a>');
+			var ttv = tts[hidden[a]],
+				tta = ttv ? ' tt="' + ttv + '">' : '>';
+
+			html.push('<a href="#" class="btn"' + tta + esc(hidden[a]) + '</a>');
 		}
 		hcols.previousSibling.style.display = html.length ? 'block' : 'none';
 		hcols.innerHTML = html.join('\n');
@@ -2673,6 +2728,10 @@ var filecols = (function () {
 			for (var b = 0, bb = tds.length; b < bb; b++)
 				tds[b].setAttribute('class', cls);
 		}
+		if (window['tt']) {
+			tt.att(ebi('hcols'));
+			tt.att(QS('#files thead'));
+		}
 	};
 	set_style();
 
@@ -2863,7 +2922,7 @@ var arcfmt = (function () {
 			["tar", "tar", "plain gnutar file"],
 			["zip", "zip=utf8", "zip with utf8 filenames (maybe wonky on windows 7 and older)"],
 			["zip_dos", "zip", "zip with traditional cp437 filenames, for really old software"],
-			["zip_crc", "zip=crc", "cp437 with crc32 computed early for truly ancient software$N(takes longer to process before download can start)"]
+			["zip_crc", "zip=crc", "cp437 with crc32 computed early,$Nfor MS-DOS PKZIP v2.04g (october 1993)$N(takes longer to process before download can start)"]
 		];
 
 	for (var a = 0; a < fmts.length; a++) {
@@ -3057,7 +3116,7 @@ function reload_browser(not_mp) {
 
 	var oo = QSA('#files>tbody>tr>td:nth-child(3)');
 	for (var a = 0, aa = oo.length; a < aa; a++) {
-		var sz = oo[a].textContent.replace(/ /g, ""),
+		var sz = oo[a].textContent.replace(/ +/g, ""),
 			hsz = sz.replace(/\B(?=(\d{3})+(?!\d))/g, " ");
 
 		oo[a].textContent = hsz;
