@@ -27,20 +27,20 @@ function vis_exh(msg, url, lineNo, columnNo, error) {
 
     window.onerror = undefined;
     window['vis_exh'] = null;
-    var html = ['<h1>you hit a bug!</h1><p>please send me a screenshot arigathanks gozaimuch: <code>ed/irc.rizon.net</code> or <code>ed#2644</code><br />&nbsp; (and if you can, press F12 and include the "Console" tab in the screenshot too)</p><p>',
-        esc(String(msg)), '</p><p>', esc(url + ' @' + lineNo + ':' + columnNo), '</p>'];
+    var html = ['<h1>you hit a bug!</h1><p style="font-size:1.3em;margin:0">try to <a href="#" onclick="localStorage.clear();location.reload();" style="text-decoration:underline;color:#fc0">reset copyparty settings</a> if you are stuck here</p><p>please send me a screenshot arigathanks gozaimuch: <code>ed/irc.rizon.net</code> or <code>ed#2644</code><br />&nbsp; (and if you can, press F12 and include the "Console" tab in the screenshot too)</p><p>',
+        esc(url + ' @' + lineNo + ':' + columnNo), '<br />' + esc(String(msg)) + '</p>'];
 
     if (error) {
         var find = ['desc', 'stack', 'trace'];
         for (var a = 0; a < find.length; a++)
             if (String(error[find[a]]) !== 'undefined')
-                html.push('<h2>' + find[a] + '</h2>' +
+                html.push('<h3>' + find[a] + '</h3>' +
                     esc(String(error[find[a]])).replace(/\n/g, '<br />\n'));
     }
     document.body.innerHTML = html.join('\n');
 
     var s = mknod('style');
-    s.innerHTML = 'body{background:#333;color:#ddd;font-family:sans-serif;font-size:0.8em;padding:0 1em 1em 1em} code{color:#bf7;background:#222;padding:.1em;margin:.2em;font-size:1.1em;font-family:monospace,monospace} *{line-height:1.5em}';
+    s.innerHTML = 'body{background:#333;color:#ddd;font-family:sans-serif;font-size:0.8em;padding:0 1em 1em 1em} h1{margin:.5em 1em 0 0;padding:0} h3{border-top:1px solid #999;margin:0} code{color:#bf7;background:#222;padding:.1em;margin:.2em;font-size:1.1em;font-family:monospace,monospace} *{line-height:1.5em}';
     document.head.appendChild(s);
 
     throw 'fatal_err';
@@ -53,6 +53,11 @@ var ebi = document.getElementById.bind(document),
     mknod = document.createElement.bind(document);
 
 
+function ctrl(e) {
+    return e && (e.ctrlKey || e.metaKey);
+}
+
+
 function ev(e) {
     e = e || window.event;
     if (!e)
@@ -497,13 +502,20 @@ function hist_replace(url) {
 var tt = (function () {
     var r = {
         "tt": mknod("div"),
-        "en": true
+        "en": true,
+        "el": null,
+        "skip": false
     };
 
     r.tt.setAttribute('id', 'tt');
     document.body.appendChild(r.tt);
 
-    function show() {
+    r.show = function () {
+        if (r.skip) {
+            r.skip = false;
+            return;
+        }
+
         var cfg = sread('tooltips');
         if (cfg !== null && cfg != '1')
             return;
@@ -512,11 +524,18 @@ var tt = (function () {
         if (!msg)
             return;
 
+        r.el = this;
         var pos = this.getBoundingClientRect(),
+            dir = this.getAttribute('ttd') || '',
             left = pos.left < window.innerWidth / 2,
             top = pos.top < window.innerHeight / 2,
             big = this.className.indexOf(' ttb') !== -1;
 
+        if (dir.indexOf('u') + 1) top = false;
+        if (dir.indexOf('d') + 1) top = true;
+        if (dir.indexOf('l') + 1) left = false;
+        if (dir.indexOf('r') + 1) left = true;
+
         clmod(r.tt, 'b', big);
         r.tt.style.top = top ? pos.bottom + 'px' : 'auto';
         r.tt.style.bottom = top ? 'auto' : (window.innerHeight - pos.top) + 'px';
@@ -524,11 +543,30 @@ var tt = (function () {
         r.tt.style.right = left ? 'auto' : (window.innerWidth - pos.right) + 'px';
 
         r.tt.innerHTML = msg.replace(/\$N/g, "<br />");
+        r.el.addEventListener('mouseleave', r.hide);
         clmod(r.tt, 'show', 1);
-    }
+    };
 
-    function hide() {
+    r.hide = function () {
         clmod(r.tt, 'show');
+        if (r.el)
+            r.el.removeEventListener('mouseleave', r.hide);
+    };
+
+    r.tt.onclick = r.hide;
+
+    r.att = function (ctr) {
+        var _show = r.en ? r.show : null,
+            _hide = r.en ? r.hide : null,
+            o = ctr.querySelectorAll('*[tt]');
+
+        for (var a = o.length - 1; a >= 0; a--) {
+            o[a].onfocus = _show;
+            o[a].onblur = _hide;
+            o[a].onmouseenter = _show;
+            o[a].onmouseleave = _hide;
+        }
+        r.hide();
     }
 
     r.init = function () {
@@ -542,18 +580,7 @@ var tt = (function () {
             };
             r.en = bcfg_get('tooltips', true)
         }
-
-        var _show = r.en ? show : null,
-            _hide = r.en ? hide : null;
-
-        var o = QSA('*[tt]');
-        for (var a = o.length - 1; a >= 0; a--) {
-            o[a].onfocus = _show;
-            o[a].onblur = _hide;
-            o[a].onmouseenter = _show;
-            o[a].onmouseleave = _hide;
-        }
-        hide();
+        r.att(document);
     };
 
     return r;
